@@ -1,4 +1,12 @@
-from hera.artifact import Artifact
+from hera.affinity import Affinity
+from hera.artifact import (
+    Artifact,
+    GCSArtifact,
+    GitArtifact,
+    InputArtifact,
+    OutputArtifact,
+    S3Artifact,
+)
 from hera.client import Client
 from hera.config import Config
 from hera.cron_workflow import CronWorkflow
@@ -6,9 +14,23 @@ from hera.cron_workflow_service import CronWorkflowService
 from hera.env import ConfigMapEnvSpec, EnvSpec, FieldEnvSpec, SecretEnvSpec
 from hera.env_from import ConfigMapEnvFromSpec, SecretEnvFromSpec
 from hera.host_alias import HostAlias
+from hera.host_config import (
+    get_global_host,
+    get_global_token,
+    set_global_host,
+    set_global_token,
+)
 from hera.image import ImagePullPolicy
-from hera.input import InputFrom
+from hera.input import (
+    GlobalInputParameter,
+    Input,
+    InputFrom,
+    InputParameter,
+    MultiInput,
+)
+from hera.memoize import Memoize
 from hera.operator import Operator
+from hera.output import Output, OutputPathParameter
 from hera.resources import Resources
 from hera.retry import Retry
 from hera.retry_policy import RetryPolicy
