@@ -12,6 +12,7 @@ from argo_workflows.models import (
     ObjectMeta,
 )
 
+from hera.affinity import Affinity
 from hera.host_alias import HostAlias
 from hera.security_context import WorkflowSecurityContext
 from hera.task import Task
@@ -33,7 +34,7 @@ class Workflow:
     ----------
     name: str
         The workflow name. Note that the workflow initiation will replace underscores with dashes.
-    service: WorkflowService
+    service: Optional[WorkflowService] = None
         A workflow service to use for submissions. See `hera.v1.workflow_service.WorkflowService`.
     parallelism: int = 50
         The number of parallel tasks to run in case a task group is executed for multiple tasks.
@@ -55,16 +56,25 @@ class Workflow:
         If you create a WorkflowTemplate resource either clusterWorkflowTemplate or not (clusterScope attribute bool)
         you can reference it again and again when you create a new Workflow without specifying the same tasks and
         dependencies. Official doc: https://argoproj.github.io/argo-workflows/fields/#workflowtemplateref
+    ttl_strategy: Optional[TTLStrategy] = None
+        The time to live strategy of the workflow.
     volume_claim_gc_strategy: Optional[VolumeClaimGCStrategy] = None
         Define how to delete volumes from completed Workflows.
     host_aliases: Optional[List[HostAlias]] = None
         Mappings between IP and hostnames.
+    node_selectors: Optional[Dict[str, str]] = None
+        A collection of key value pairs that denote node selectors. This is used for scheduling purposes. If the task
+        requires GPU resources, clients are encouraged to add a node selector for a node that can satisfy the
+        requested resources. In addition, clients are encouraged to specify a GPU toleration, depending on the platform
+        they submit the workflow to.
+    affinity: Optional[Affinity] = None
+        The task affinity. This dictates the scheduling protocol of the pods running the tasks of the workflow.
     """
 
     def __init__(
         self,
         name: str,
-        service: WorkflowService,
+        service: Optional[WorkflowService] = None,
         parallelism: int = 50,
         service_account_name: Optional[str] = None,
         labels: Optional[Dict[str, str]] = None,
@@ -76,10 +86,12 @@ class Workflow:
         ttl_strategy: Optional[TTLStrategy] = None,
         volume_claim_gc_strategy: Optional[VolumeClaimGCStrategy] = None,
         host_aliases: Optional[List[HostAlias]] = None,
+        node_selectors: Optional[Dict[str, str]] = None,
+        affinity: Optional[Affinity] = None,
     ):
         self.name = f'{name.replace("_", "-")}'  # RFC1123
         self.namespace = namespace or 'default'
-        self.service = service
+        self.service = service or WorkflowService()
         self.parallelism = parallelism
         self.security_context = security_context
         self.service_account_name = service_account_name
@@ -87,6 +99,9 @@ class Workflow:
         self.annotations = annotations
         self.image_pull_secrets = image_pull_secrets
         self.workflow_template_ref = workflow_template_ref
+        self.node_selector = node_selectors
+        self.ttl_strategy = ttl_strategy
+        self.affinity = affinity
 
         self.dag_template = IoArgoprojWorkflowV1alpha1DAGTemplate(tasks=[])
         self.exit_template = IoArgoprojWorkflowV1alpha1Template(
@@ -146,12 +161,21 @@ class Workflow:
             secret_refs = [LocalObjectReference(name=name) for name in self.image_pull_secrets]
             setattr(self.spec, 'image_pull_secrets', secret_refs)
 
+        if self.affinity:
+            setattr(self.exit_template, 'affinity', self.affinity.get_spec())
+            setattr(self.template, 'affinity', self.affinity.get_spec())
+
         self.metadata = ObjectMeta(name=self.name)
         if self.labels:
             setattr(self.metadata, 'labels', self.labels)
         if self.annotations:
             setattr(self.metadata, 'annotations', self.annotations)
 
+        if self.node_selector:
+            setattr(self.dag_template, 'node_selector', self.node_selector)
+            setattr(self.template, 'node_selector', self.node_selector)
+            setattr(self.exit_template, 'node_selector', self.node_selector)
+
         self.workflow = IoArgoprojWorkflowV1alpha1Workflow(metadata=self.metadata, spec=self.spec)
 
     def add_task(self, t: Task) -> None:
